# AppOmni Spellbook Utilities

Purpose of this library is to provide some utilities to facilitate interaction with the Spellbook definitions.

This library is currently targeting Python 3.10 for minimum support level.